==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/modules/payment/cod.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	cod.lang.inc.php 2017-05-10 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2017 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_PAYMENT_COD_ALLOWED_DESC' => 'Geben Sie <b>einzeln</b> die Zonen an, welche für dieses Modul erlaubt sein sollen. (z.B. AT,DE (wenn leer, werden alle Zonen erlaubt))',
	'MODULE_PAYMENT_COD_ALLOWED_TITLE' => 'Erlaubte Zonen',
	'MODULE_PAYMENT_COD_ORDER_STATUS_ID_DESC' => 'Bestellungen, welche mit diesem Modul gemacht werden, auf diesen Status setzen',
	'MODULE_PAYMENT_COD_ORDER_STATUS_ID_TITLE' => 'Bestellstatus festlegen',
	'MODULE_PAYMENT_COD_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige. Kleinste Ziffer wird zuerst angezeigt.',
	'MODULE_PAYMENT_COD_SORT_ORDER_TITLE' => 'Anzeigereihenfolge',
	'MODULE_PAYMENT_COD_STATUS_DESC' => 'Möchten Sie Zahlungen per Nachnahme akzeptieren?',
	'MODULE_PAYMENT_COD_STATUS_TITLE' => 'Nachnahme Modul aktivieren',
	'MODULE_PAYMENT_COD_TEXT_DESCRIPTION' => 'Nachnahme',
	'MODULE_PAYMENT_COD_TEXT_INFO' => 'Zahlung per Nachnahme',
	'MODULE_PAYMENT_COD_TEXT_TITLE' => 'Nachnahme',
	'MODULE_PAYMENT_COD_ZONE_DESC' => 'Wenn eine Zone ausgewählt ist, gilt die Zahlungsmethode nur für diese Zone.',
	'MODULE_PAYMENT_COD_ZONE_TITLE' => 'Zahlungszone',
	'MODULE_PAYMENT_COD_UPPER_LIMIT_DESC' => 'Legt eine Obergrenze fest, bis zu welcher Gesamtsumme die Bezahlung per Nachnahme erlaubt wird (z.B. 2500.00).',
	'MODULE_PAYMENT_COD_UPPER_LIMIT_TITLE' => 'Warenkorb Obergrenze',
	'MODULE_PAYMENT_COD_DISABLED_SHIPPINGS_DESC' => 'Legt die Versandarten fest, für die diese Zahlungsweise nicht angezeigt werden soll. Trennen Sie die einzelnen Versandmodule (Modulnamen) durch ein Komma. (z.B. "flat,freeamount" für Pauschale Versandkosten und Versandkostenfrei)',
	'MODULE_PAYMENT_COD_DISABLED_SHIPPINGS_TITLE' => 'Ausschließende Versandarten',
	'MODULE_PAYMENT_TYPE_PERMISSION' => 'cod'
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/modules/payment/cod.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	cod.lang.inc.php 2017-05-10 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2017 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_PAYMENT_COD_ALLOWED_DESC' => 'Gib <b>einzeln</b> die Zonen an, welche für dieses Modul erlaubt sein sollen. (z.B. AT,DE (wenn leer, werden alle Zonen erlaubt))',
	'MODULE_PAYMENT_COD_ALLOWED_TITLE' => 'Erlaubte Zonen',
	'MODULE_PAYMENT_COD_ORDER_STATUS_ID_DESC' => 'Bestellungen, welche mit diesem Modul gemacht werden, auf diesen Status setzen',
	'MODULE_PAYMENT_COD_ORDER_STATUS_ID_TITLE' => 'Bestellstatus festlegen',
	'MODULE_PAYMENT_COD_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige. Kleinste Ziffer wird zuerst angezeigt.',
	'MODULE_PAYMENT_COD_SORT_ORDER_TITLE' => 'Anzeigereihenfolge',
	'MODULE_PAYMENT_COD_STATUS_DESC' => 'Möchtest du Zahlungen per Nachnahme akzeptieren?',
	'MODULE_PAYMENT_COD_STATUS_TITLE' => 'Nachnahme Modul aktivieren',
	'MODULE_PAYMENT_COD_TEXT_DESCRIPTION' => 'Nachnahme',
	'MODULE_PAYMENT_COD_TEXT_INFO' => 'Zahlung per Nachnahme',
	'MODULE_PAYMENT_COD_TEXT_TITLE' => 'Nachnahme',
	'MODULE_PAYMENT_COD_ZONE_DESC' => 'Wenn eine Zone ausgewählt ist, gilt die Zahlungsmethode nur für diese Zone.',
	'MODULE_PAYMENT_COD_ZONE_TITLE' => 'Zahlungszone',
	'MODULE_PAYMENT_COD_UPPER_LIMIT_DESC' => 'Legt eine Obergrenze fest, bis zu welcher Gesamtsumme die Bezahlung per Nachnahme erlaubt wird (z.B. 2500.00).',
	'MODULE_PAYMENT_COD_UPPER_LIMIT_TITLE' => 'Warenkorb Obergrenze',
	'MODULE_PAYMENT_COD_DISABLED_SHIPPINGS_DESC' => 'Legt die Versandarten fest, für die diese Zahlungsweise nicht angezeigt werden soll. Trenne die einzelnen Versandmodule (Modulnamen) durch ein Komma. (z.B. "flat,freeamount" für Pauschale Versandkosten und Versandkostenfrei)',
	'MODULE_PAYMENT_COD_DISABLED_SHIPPINGS_TITLE' => 'Ausschließende Versandarten',
	'MODULE_PAYMENT_TYPE_PERMISSION' => 'cod'
);
